from django.urls import path
from . import views
app_name = 'custom'
urlpatterns = [
	path('ajax/load-posts/', views.load_posts, name='ajax_load_posts'),
	path('ajax/load-villages/', views.load_villages, name='ajax_load_villages'),
	path('ajax/load-aldeia/', views.load_aldeia, name='ajax_load_aldeia'),
]




from django.contrib import admin
from .models import *


from import_export import resources

from import_export.admin import ImportExportModelAdmin



class MunicipalityResource(resources.ModelResource):
    class Meta:
        model = Municipality
class MunicipalityAdmin(ImportExportModelAdmin):
    resource_class = MunicipalityResource
admin.site.register(Municipality, MunicipalityAdmin)



class AdministrativePostResource(resources.ModelResource):
    class Meta:
        model = AdministrativePost
class AdministrativePostAdmin(ImportExportModelAdmin):
    resource_class = AdministrativePostResource
admin.site.register(AdministrativePost, AdministrativePostAdmin)



class VillageResource(resources.ModelResource):
    class Meta:
        model = Village
class VillageAdmin(ImportExportModelAdmin):
    resource_class = VillageResource
admin.site.register(Village, VillageAdmin)

class AldeiaResource(resources.ModelResource):
    class Meta:
        model = Aldeia
class AldeiaAdmin(ImportExportModelAdmin):
    resource_class = AldeiaResource
admin.site.register(Aldeia, AldeiaAdmin)



class YearResource(resources.ModelResource):
    class Meta:
        model = Year
class YearAdmin(ImportExportModelAdmin):
    resource_class = YearResource
admin.site.register(Year, YearAdmin)


import os
import hashlib

def upload_files(instance, filename):
	upload_to = 'project_letters/{}/'.format(instance.project_letter.project.project_code)
	number = instance.project_letter.number.replace("/", "-")
	field = 'files'
	ext = filename.split('.')[-1]
	if instance.pk:
		filename = '{}_{}_{}_{}.{}'.format(field,instance.project_letter.letter_date,number,instance.pk, ext)
	else:
		filename = '{}.{}'.format(uuid4().hex, ext)
	return os.path.join(upload_to, filename)


def getnewid(table_name):
	result = table_name.objects.last()
	if result:
		newid = result.id + 1
		hashid = hashlib.md5(str(newid).encode())
	else:
		newid = 1
		hashid = hashlib.md5(str(newid).encode())
	return newid, hashid.hexdigest()

def getjustnewid(table_name):
	result = table_name.objects.last()
	if result:
		newid = result.id + 1
	else:
		newid = 1
	return newid
	 
def onlygetnewid(table_name):
	result = table_name.objects.latest("id")
	if result:
		newid = result.id + 1
	else:
		newid = 1
	return newid

def getlastid(table_name):
	result = table_name.objects.last()
	if result:
		lastid = result.id
		newid = lastid + 1
	else:
		lastid = 0
		newid = 1
	return lastid, newid

def hash_md5(strhash):
	hashed = hashlib.md5(strhash.encode())
	return hashed.hexdigest()



from django.db import models


class Municipality(models.Model):
	code = models.CharField(max_length=5, null=True, blank = True)
	name = models.CharField(max_length=100)
	hckey = models.CharField(max_length=10, null=True ,  blank = True)
	def __str__(self):
		template = '{0.name}'
		return template.format(self)

	class Meta:
		verbose_name_plural = 'Dadus Custom Ba Munisipiu'

class AdministrativePost(models.Model):
	municipality = models.ForeignKey(Municipality, on_delete=models.CASCADE, null=True)
	name = models.CharField(max_length=100)
	def __str__(self):
		template = '{0.name}'
		return template.format(self)
	class Meta:
		verbose_name_plural = 'Dadus Custom Ba Postu Administrativu'

class Village(models.Model):
	administrativepost = models.ForeignKey(AdministrativePost, on_delete=models.CASCADE, null=True)
	name = models.CharField(max_length=100)
	def __str__(self):
		template = '{0.name}'
		return template.format(self)

	class Meta:
		verbose_name_plural = 'Dadus Custom Ba Suku'

class Aldeia(models.Model):
	village = models.ForeignKey(Village, on_delete=models.CASCADE, null=True)
	name = models.CharField(max_length=100)
	def __str__(self):
		template = '{0.name}'
		return template.format(self)
	class Meta:
		verbose_name_plural = 'Dadus Custom Ba Aldeia'

class Year(models.Model):
	year = models.IntegerField()
	active = models.BooleanField(default=False)
	def __str__(self):
		template = '{0.year}'
		return template.format(self)
	class Meta:

		verbose_name_plural = 'Dadus Custom Ba Tinan'





from django.shortcuts import render
from .models import *
from employee.models import *


def load_posts(request):
	mun_id = request.GET.get('municipality')
	posts = AdministrativePost.objects.filter(municipality_id=mun_id).order_by('name')
	return render(request, 'custom/posts_dropdown.html', {'posts': posts})

def load_villages(request):
	post_id = request.GET.get('post')
	villages = Village.objects.filter(administrativepost_id=post_id).order_by('name')
	return render(request, 'custom/villages_dropdown.html', {'villages': villages})

def load_aldeia(request):
	post_id = request.GET.get('post')
	aldeia = Aldeia.objects.filter(village_id=post_id).order_by('name')
	print(aldeia)
	return render(request, 'custom/aldeia_dropdown.html', {'aldeia': aldeia})
